Welcome to pyemtmad's documentation!
====================================

pyemtmad is a wrapper for the EMT API available at
`<http://opendata.emtmadrid.es/Servicios-web>`_. 

**Released under GPLv2+ license.**

Latest version: **0.1.0**

Contents:

.. toctree::
   :hidden:

   self

.. toctree::
   :maxdepth: 1

   quickstart

.. toctree::
   :maxdepth: 4

   pyemtmad


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

